summaryrefslogtreecommitdiff
path: root/makima/frontend/src/components/mesh/TaskList.tsx
diff options
context:
space:
mode:
Diffstat (limited to 'makima/frontend/src/components/mesh/TaskList.tsx')
-rw-r--r--makima/frontend/src/components/mesh/TaskList.tsx8
1 files changed, 4 insertions, 4 deletions
diff --git a/makima/frontend/src/components/mesh/TaskList.tsx b/makima/frontend/src/components/mesh/TaskList.tsx
index f829b29..80077b6 100644
--- a/makima/frontend/src/components/mesh/TaskList.tsx
+++ b/makima/frontend/src/components/mesh/TaskList.tsx
@@ -95,8 +95,8 @@ export function TaskList({
// Group tasks by contract and filter by status
const groupedTasks = useMemo(() => {
- // Separate root tasks (no parent) from subtasks
- const rootTasks = tasks.filter((t) => !t.parentTaskId);
+ // Separate root tasks (no parent) from subtasks, and only show supervisor tasks
+ const rootTasks = tasks.filter((t) => !t.parentTaskId && t.isSupervisor);
// Filter tasks based on contract status
const filteredTasks = statusFilter === 'all'
@@ -205,8 +205,8 @@ export function TaskList({
{totalTasks === 0 ? (
<div className="text-center text-[#9bc3ff] text-sm font-mono opacity-60 py-8">
{statusFilter === 'all'
- ? 'No tasks yet. Create one to start orchestrating Claude Code instances.'
- : `No ${statusFilter} tasks found.`}
+ ? 'No supervisor tasks yet. Create a contract to start orchestrating tasks.'
+ : `No ${statusFilter} supervisor tasks found.`}
</div>
) : (
<div>